#!/usr/bin/perl

use strict;
use warnings;

use Test::More tests => 1;

BEGIN {
    use_ok('Module::Build::Convert');
}

diag("Testing Module::Build::Convert $Module::Build::Convert::VERSION, Perl $], $^X");
